@@ -32,6 +32,10 @@ from collections import Counter
 # 折线图、面积图；
 class Line_Py:
     def __init__(self, title, x_value, y_name, y_value, *args, pos_top='top', is_zoom=False, boundary_gap=False, is_orient='horizontal', y_is_inverse=False, x_is_inverse=False, legend_icon='roundRect', subtitle='', is_symbol_show=False, line_width=2, is_show=False, color_list=['#00b088', '#f76b61', '#ffb55d', '#8470ff', '#00a2ff', '#ffe400', '#11d2c2', '#c263f9']):
+        """
+            * 若是有args传参，参数示例：*[['1', '2', '3'], [[136,176, 177], [209, 163, 223], [244, 235, 321]]；
+            * 第一个列表是Y轴的数据名称列表，第二个列表是每个Y轴对应的数据；
+        """
         self.pos_top = pos_top
         self.legend_icon = legend_icon
         self.is_zoom = is_zoom
